@@ -1,5 +1,5 @@
 /*
- * $Id: winmain.c,v 1.101.2.2 2017/07/30 07:52:31 markisch Exp $
+ * $Id: winmain.c,v 1.101.2.3 2017/10/31 00:14:38 sfeam Exp $
  */
 
 /* GNUPLOT - win/winmain.c */
@@ -1208,9 +1208,12 @@ static int
 ConsolePutS(const char *str)
 {
     LPWSTR wstr = UnicodeText(str, encoding);
-    HANDLE h = GetStdHandle(STD_OUTPUT_HANDLE);
-    WriteConsoleW(h, wstr, wcslen(wstr), NULL, NULL);
-    //fputws(wstr, stdout);
+    // Use standard file IO instead of Console API
+    // to enable word-wrapping on Windows 10 and
+    // allow for redirection of stdout/stderr.
+    //HANDLE h = GetStdHandle(STD_OUTPUT_HANDLE);
+    //WriteConsoleW(h, wstr, wcslen(wstr), NULL, NULL);
+    fputws(wstr, stdout);
     free(wstr);
     return 0;
 }
@@ -1219,13 +1222,17 @@ ConsolePutS(const char *str)
 static int
 ConsolePutCh(int ch)
 {
-    WCHAR w[3];
+    WCHAR w[4];
     int count;
 
     MultiByteAccumulate(ch, w, &count);
     if (count > 0) {
-	HANDLE h = GetStdHandle(STD_OUTPUT_HANDLE);
-	WriteConsoleW(h, w, count, NULL, NULL);
+	// Use standard file IO instead of Console API
+	// to enable word-wrapping on Windows 10.
+	//HANDLE h = GetStdHandle(STD_OUTPUT_HANDLE);
+	//WriteConsoleW(h, w, count, NULL, NULL);
+	w[count] = 0;
+	fputws(w, stdout);
     }
     return ch;
 }
